Learn R Programming

GenVisR (version 1.0.2)

geneViz_mapCoordSpace: Map regions to transformed space

Description

Reference a master genomic region file to map original positions to a transformed space

Usage

geneViz_mapCoordSpace(master, coord)

Arguments

master
an object of class data frame containing columns start, end, width, type, trans_start, trans_end representing a master genomic region with features from isoforms merged
coord
an object of class data frame containing columns start and end to map to transformed space

Value

  • an object of class data frame identical to coord but with extra columns for transformed coord